@@ -7,11 +7,14 @@
 #include "account/accountmanager.h"
 #include "account/relationship.h"
 #include "network/networkcontroller.h"
-#include "tokodon_debug.h"
 #include "utils/messagefiltercontainer.h"
 #include "utils/navigation.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
+#include <QUrlQuery>
+#include <qmimedatabase.h>
 
 using namespace Qt::Literals::StringLiterals;
 
@@ -25,6 +28,21 @@ AbstractAccount::AbstractAccount(const QString &instanceUri, QObject *parent)
     , m_charactersReservedPerUrl(23)
     , m_identity(std::make_shared<Identity>())
     , m_preferences(new Preferences(this))
+    , m_notificationFilteringPolicy(new NotificationFilteringPolicy(this))
+    , m_maxMediaAttachments(4)
+    , m_attachmentFilterStrings({i18n("All supported formats (*.jpg *.jpeg *.png *.gif *.webp *.heic *.heif *.avif *.webm *.mp4 *.m4v *.mov)"),
+                                 i18n("JPEG image (*.jpg *.jpeg)"),
+                                 i18n("PNG image (*.png)"),
+                                 i18n("GIF image (*.gif)"),
+                                 i18n("WebP image (*.webp)"),
+                                 i18n("HEIC image(*.heic)"),
+                                 i18n("HEIF image (*.heif)"),
+                                 i18n("AVIF image (*.avif)"),
+                                 i18n("WebM video (*.webm)"),
+                                 i18n("MPEG-4 video (*.mp4)"),
+                                 i18n("M4V video (*.m4v)"),
+                                 i18n("QuickTime video (*.mov)"),
+                                 i18n("All files (*)")})
 {
     // Test code uses a blank instance URI
     if (!AccountManager::instance().testMode()) {
@@ -49,6 +67,11 @@ Preferences *AbstractAccount::preferences() const
     return m_preferences;
 }
 
+NotificationFilteringPolicy *AbstractAccount::notificationFilteringPolicy() const
+{
+    return m_notificationFilteringPolicy;
+}
+
 QString AbstractAccount::username() const
 {
     return m_name;
@@ -149,7 +172,7 @@ void AbstractAccount::registerApplication(const QString &appName, const QString
         Qt::SingleShotConnection);
 #endif
 
-    post(regUrl, doc, false, this, [=](QNetworkReply *reply) {
+    post(regUrl, doc, false, this, [this](QNetworkReply *reply) {
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
@@ -181,7 +204,7 @@ void AbstractAccount::registerAccount(const QString &username,
     q.addQueryItem(QStringLiteral("grant_type"), QStringLiteral("client_credentials"));
     q.addQueryItem(QStringLiteral("scope"), QStringLiteral("write"));
 
-    post(tokenUrl, q, false, this, [=](QNetworkReply *reply) {
+    post(tokenUrl, q, false, this, [this, username, email, password, agreement, locale, reason](QNetworkReply *reply) {
         auto data = reply->readAll();
         auto doc = QJsonDocument::fromJson(data);
 
@@ -202,7 +225,7 @@ void AbstractAccount::registerAccount(const QString &username,
             formdata,
             true,
             this,
-            [=](QNetworkReply *reply) {
+            [this, username](QNetworkReply *reply) {
                 const auto data = reply->readAll();
                 const auto doc = QJsonDocument::fromJson(data);
 
@@ -211,7 +234,7 @@ void AbstractAccount::registerAccount(const QString &username,
                     setAccessToken(doc["access_token"_L1].toString());
                 }
             },
-            [=](QNetworkReply *reply) {
+            [this](QNetworkReply *reply) {
                 Q_EMIT registrationError(QString::fromUtf8(reply->readAll()));
             });
     });
@@ -343,7 +366,7 @@ void AbstractAccount::setToken(const QString &authcode)
     q.addQueryItem(QStringLiteral("grant_type"), QStringLiteral("authorization_code"));
     q.addQueryItem(QStringLiteral("code"), authcode);
 
-    post(tokenUrl, q, false, this, [=](QNetworkReply *reply) {
+    post(tokenUrl, q, false, this, [this](QNetworkReply *reply) {
         auto data = reply->readAll();
         auto doc = QJsonDocument::fromJson(data);
 
@@ -356,7 +379,7 @@ void AbstractAccount::mutatePost(const QString &id, const QString &verb, bool de
     const QUrl mutation_url = apiUrl(QStringLiteral("/api/v1/statuses/%1/%2").arg(id, verb));
     const QJsonDocument doc;
 
-    post(mutation_url, doc, true, this, [=](QNetworkReply *reply) {
+    post(mutation_url, doc, true, this, [this, deliver_home](QNetworkReply *reply) {
         const auto data = reply->readAll();
         const auto doc = QJsonDocument::fromJson(data);
 
@@ -412,13 +435,23 @@ void AbstractAccount::unpin(Post *p)
     mutatePost(p->postId(), QStringLiteral("unpin"));
 }
 
+void AbstractAccount::mute(Post *p)
+{
+    mutatePost(p->postId(), QStringLiteral("mute"), false);
+}
+
+void AbstractAccount::unmute(Post *p)
+{
+    mutatePost(p->postId(), QStringLiteral("unmute"), false);
+}
+
 void AbstractAccount::fetchInstanceMetadata()
 {
     get(
         apiUrl(QStringLiteral("/api/v2/instance")),
         false,
         this,
-        [=](QNetworkReply *reply) {
+        [this](QNetworkReply *reply) {
             const auto data = reply->readAll();
             const auto doc = QJsonDocument::fromJson(data);
 
@@ -435,6 +468,27 @@ void AbstractAccount::fetchInstanceMetadata()
                     const auto statusConfigObj = configObj["statuses"_L1].toObject();
                     m_maxPostLength = statusConfigObj["max_characters"_L1].toInt();
                     m_charactersReservedPerUrl = statusConfigObj["characters_reserved_per_url"_L1].toInt();
+                    m_maxMediaAttachments = statusConfigObj["max_media_attachments"_L1].toInt();
+                }
+
+                if (configObj.contains("media_attachments"_L1)) {
+                    const auto statusConfigObj = configObj["media_attachments"_L1].toObject();
+                    if (statusConfigObj.contains("supported_mime_types"_L1)) {
+                        m_attachmentFilterStrings.clear();
+                        QStringList allGlobs;
+                        QMimeDatabase db;
+                        for (const auto &mimeTypeName : statusConfigObj["supported_mime_types"_L1].toArray()) {
+                            // FIXME: Some mimetypes such as audio/webm do not have a filter string for some reason.
+                            const auto mimeType = db.mimeTypeForName(mimeTypeName.toString());
+                            if (mimeType.isValid() && !mimeType.filterString().isEmpty() && !m_attachmentFilterStrings.contains(mimeType.filterString())) {
+                                m_attachmentFilterStrings.push_back(mimeType.filterString());
+                                allGlobs.append(mimeType.globPatterns());
+                            }
+                        }
+
+                        m_attachmentFilterStrings.prepend(i18n("All supported formats (%1)", allGlobs.join(QLatin1Char(' '))));
+                        m_attachmentFilterStrings.push_back(i18n("All files (*)"));
+                    }
                 }
             }
 
@@ -464,10 +518,10 @@ void AbstractAccount::fetchInstanceMetadata()
 
             Q_EMIT fetchedInstanceMetadata();
         },
-        [=](QNetworkReply *) {
+        [this](QNetworkReply *) {
             // Fall back to v1 instance information
             // TODO: a lot of this can be merged with v2 handling
-            get(apiUrl(QStringLiteral("/api/v1/instance")), false, this, [=](QNetworkReply *reply) {
+            get(apiUrl(QStringLiteral("/api/v1/instance")), false, this, [this](QNetworkReply *reply) {
                 const auto data = reply->readAll();
                 const auto doc = QJsonDocument::fromJson(data);
 
@@ -575,7 +629,7 @@ void AbstractAccount::executeAction(Identity *identity, AccountAction accountAct
     const QString accountApiUrl = QStringLiteral("/api/v1/accounts/%1%2").arg(accountId, apiCall);
     const QJsonDocument doc(extraArguments);
 
-    post(apiUrl(accountApiUrl), doc, true, this, [=](QNetworkReply *reply) {
+    post(apiUrl(accountApiUrl), doc, true, this, [this, accountAction, identity](QNetworkReply *reply) {
         auto doc = QJsonDocument::fromJson(reply->readAll());
         auto jsonObj = doc.object();
 
@@ -625,6 +679,16 @@ int AbstractAccount::unreadNotificationsCount() const
     return m_unreadNotificationsCount;
 }
 
+int AbstractAccount::maxMediaAttachments() const
+{
+    return m_maxMediaAttachments;
+}
+
+QStringList AbstractAccount::attachmentFilterStrings() const
+{
+    return m_attachmentFilterStrings;
+}
+
 void AbstractAccount::followAccount(Identity *identity, bool reblogs, bool notify)
 {
     executeAction(identity,
@@ -686,7 +750,7 @@ void AbstractAccount::addNote(Identity *identity, const QString &note)
 
 void AbstractAccount::mutateRemotePost(const QString &url, const QString &verb)
 {
-    requestRemoteObject(QUrl(url), this, [=](QNetworkReply *reply) {
+    requestRemoteObject(QUrl(url), this, [this, verb](QNetworkReply *reply) {
         const auto searchResult = QJsonDocument::fromJson(reply->readAll()).object();
         const auto statuses = searchResult[QStringLiteral("statuses")].toArray();
         const auto accounts = searchResult[QStringLiteral("accounts")].toArray();
@@ -753,7 +817,7 @@ void AbstractAccount::fetchCustomEmojis()
 {
     m_customEmojis.clear();
 
-    get(apiUrl(QStringLiteral("/api/v1/custom_emojis")), true, this, [=](QNetworkReply *reply) {
+    get(apiUrl(QStringLiteral("/api/v1/custom_emojis")), true, this, [this](QNetworkReply *reply) {
         if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute))
             return;
 
@@ -786,4 +850,27 @@ QList<CustomEmoji> AbstractAccount::customEmojis() const
     return m_customEmojis;
 }
 
+void AbstractAccount::addFavoriteList(const QString &id)
+{
+    auto ids = config()->favoriteListIds();
+    ids.push_back(id);
+    config()->setFavoriteListIds(ids);
+    config()->save();
+    Q_EMIT favoriteListsChanged();
+}
+
+void AbstractAccount::removeFavoriteList(const QString &id)
+{
+    auto ids = config()->favoriteListIds();
+    ids.removeAll(id);
+    config()->setFavoriteListIds(ids);
+    config()->save();
+    Q_EMIT favoriteListsChanged();
+}
+
+bool AbstractAccount::isFavoriteList(const QString &id)
+{
+    return config()->favoriteListIds().contains(id);
+}
+
 #include "moc_abstractaccount.cpp"
