@@ -16,6 +16,12 @@
 #include "messagefiltercontainer.h"
 #include "tokodon-version.h"
 
+#include <QFileInfo>
+#include <QHttpMultiPart>
+#include <QJsonDocument>
+#include <QNetworkReply>
+#include <QRandomGenerator>
+#include <QUrlQuery>
 #include <config.h>
 #include <qt6keychain/keychain.h>
 
@@ -155,6 +161,7 @@ void Account::deleteResource(const QUrl &url, bool authenticated, QObject *paren
 QNetworkRequest Account::makeRequest(const QUrl &url, bool authenticated) const
 {
     QNetworkRequest request(url);
+    request.setTransferTimeout(Config::timeout());
 
     if (authenticated && haveToken()) {
         const QByteArray bearer = QStringLiteral("Bearer %1").arg(m_token).toLocal8Bit();
@@ -172,13 +179,9 @@ void Account::handleReply(QNetworkReply *reply, std::function<void(QNetworkReply
     connect(reply, &QNetworkReply::finished, [reply, reply_cb, errorCallback]() {
         reply->deleteLater();
         if (200 != reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) && !reply->url().toString().contains("nodeinfo"_L1)) {
+            NetworkController::instance().logError(reply->url().toString(), reply->errorString());
             if (errorCallback) {
-                // If the error is handled, then only emit it for people interested in debug logs
-                qCDebug(TOKODON_HTTP) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
                 errorCallback(reply);
-            } else {
-                qCWarning(TOKODON_HTTP) << reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) << reply->url();
-                Q_EMIT NetworkController::instance().networkErrorOccurred(reply->errorString());
             }
             return;
         }
@@ -250,7 +253,7 @@ QWebSocket *Account::streamingSocket(const QString &stream)
 
     const auto url = streamingUrl(stream);
 
-    connect(socket, &QWebSocket::textMessageReceived, this, [=](const QString &message) {
+    connect(socket, &QWebSocket::textMessageReceived, this, [this](const QString &message) {
         const auto env = QJsonDocument::fromJson(message.toLocal8Bit());
         if (env.isObject() && env.object().contains("event"_L1)) {
             const auto event = stringToStreamingEventType[env.object()["event"_L1].toString()];
@@ -266,7 +269,7 @@ QWebSocket *Account::streamingSocket(const QString &stream)
         }
     });
     connect(socket, &QWebSocket::errorOccurred, this, [=](QAbstractSocket::SocketError) {
-        qCWarning(TOKODON_HTTP) << "Error in" << stream << ":" << socket->errorString();
+        NetworkController::instance().logError(url.toString(), socket->errorString());
     });
 
     QNetworkRequest request(url);
@@ -319,7 +322,7 @@ void Account::validateToken()
                 apiUrl(QStringLiteral("/api/v1/push/subscription")),
                 true,
                 this,
-                [=](QNetworkReply *reply) {
+                [this](QNetworkReply *reply) {
                     m_hasPushSubscription = true;
 
                     const QJsonDocument doc = QJsonDocument::fromJson(reply->readAll());
@@ -327,7 +330,7 @@ void Account::validateToken()
                     if (!NetworkController::instance().endpoint.isEmpty() && doc["endpoint"_L1] != NetworkController::instance().endpoint) {
                         qWarning(TOKODON_LOG) << "KUnifiedPush endpoint has changed to" << NetworkController::instance().endpoint << ", resubscribing!";
 
-                        deleteResource(apiUrl(QStringLiteral("/api/v1/push/subscription")), true, this, [=](QNetworkReply *reply) {
+                        deleteResource(apiUrl(QStringLiteral("/api/v1/push/subscription")), true, this, [this](QNetworkReply *reply) {
                             Q_UNUSED(reply)
                             m_hasPushSubscription = false;
                             subscribePushNotifications();
@@ -336,14 +339,14 @@ void Account::validateToken()
                         updatePushNotifications();
                     }
                 },
-                [=](QNetworkReply *reply) {
+                [this](QNetworkReply *reply) {
                     Q_UNUSED(reply);
                     m_hasPushSubscription = false;
                     updatePushNotifications();
                 });
 #endif
         },
-        [=](QNetworkReply *reply) {
+        [this](QNetworkReply *reply) {
             const auto doc = QJsonDocument::fromJson(reply->readAll());
 
             Q_EMIT authenticated(false, doc.isEmpty() ? reply->errorString() : doc["error"_L1].toString());
@@ -430,22 +433,14 @@ void Account::checkForFollowRequests()
 
 void Account::checkForUnreadNotifications()
 {
-    get(
-        apiUrl(QStringLiteral("/api/v1/notifications/unread_count")),
-        true,
-        this,
-        [this](QNetworkReply *reply) {
-            const auto unreadNotificationsObject = QJsonDocument::fromJson(reply->readAll());
-            const auto count = unreadNotificationsObject["count"_L1].toInt();
-            if (m_unreadNotificationsCount != count) {
-                m_unreadNotificationsCount = count;
-                Q_EMIT unreadNotificationsCountChanged();
-            }
-        },
-        [](QNetworkReply *reply) {
-            Q_UNUSED(reply)
-            // This error can be safely ignored
-        });
+    get(apiUrl(QStringLiteral("/api/v1/notifications/unread_count")), true, this, [this](QNetworkReply *reply) {
+        const auto unreadNotificationsObject = QJsonDocument::fromJson(reply->readAll());
+        const auto count = unreadNotificationsObject["count"_L1].toInt();
+        if (m_unreadNotificationsCount != count) {
+            m_unreadNotificationsCount = count;
+            Q_EMIT unreadNotificationsCountChanged();
+        }
+    });
 }
 
 void Account::updatePushNotifications()
@@ -478,7 +473,7 @@ void Account::unsubscribePushNotifications()
 {
 #ifdef HAVE_KUNIFIEDPUSH
     Q_ASSERT(m_hasPushSubscription);
-    deleteResource(apiUrl(QStringLiteral("/api/v1/push/subscription")), true, this, [=](QNetworkReply *reply) {
+    deleteResource(apiUrl(QStringLiteral("/api/v1/push/subscription")), true, this, [this](QNetworkReply *reply) {
         m_hasPushSubscription = false;
         qCDebug(TOKODON_HTTP) << "Unsubscribed from push notifications:" << reply->readAll();
     });
@@ -512,7 +507,7 @@ void Account::subscribePushNotifications()
         formdata,
         true,
         this,
-        [=](QNetworkReply *reply) {
+        [this](QNetworkReply *reply) {
             m_hasPushSubscription = true;
             qCDebug(TOKODON_HTTP) << "Subscribed to push notifications:" << reply->readAll();
         },
@@ -541,6 +536,7 @@ QUrlQuery Account::buildNotificationFormData()
     addQuery(QStringLiteral("update"), cfg->notifyUpdate());
     addQuery(QStringLiteral("admin.sign_up"), cfg->notifySignup());
     addQuery(QStringLiteral("admin.report"), cfg->notifyReport());
+    addQuery(QStringLiteral("annual_report"), cfg->notifyAnnualReport());
 
     return formdata;
 }
