@@ -2,6 +2,9 @@
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "autotests/mockaccount.h"
+
+#include <QJsonDocument>
+
 #include "account/notificationhandler.h"
 #include "autotests/helperreply.h"
 
@@ -10,8 +13,10 @@ using namespace Qt::Literals::StringLiterals;
 MockAccount::MockAccount(QObject *parent)
     : AbstractAccount({}, parent)
 {
+    m_errorReply = new TestReply(QStringLiteral("error.json"), this);
     registerGet(apiUrl(QStringLiteral("/api/v1/preferences")), new TestReply(QStringLiteral("preferences.json"), this));
     m_preferences = new Preferences(this);
+    m_notificationFilteringPolicy = new NotificationFilteringPolicy(this);
     auto notificationHandler = new NotificationHandler(new QNetworkAccessManager, this);
     connect(this, &MockAccount::notification, notificationHandler, [this, notificationHandler](std::shared_ptr<Notification> notification) {
         notificationHandler->handle(notification, this);
@@ -43,7 +48,7 @@ void MockAccount::get(const QUrl &url,
     } else {
         qWarning() << "Cannot find reply for " << url;
         if (errorCallback)
-            errorCallback(nullptr);
+            errorCallback(m_errorReply);
     }
 }
 
@@ -223,6 +228,16 @@ void MockAccount::pollNotification()
     readNotificationFromFile("notification_poll.json"_L1);
 }
 
+void MockAccount::annualReportNotification()
+{
+    readNotificationFromFile("notification_annual_report.json"_L1);
+}
+
+void MockAccount::unknownNotification()
+{
+    readNotificationFromFile("notification_unknown.json"_L1);
+}
+
 void MockAccount::increaseFollowRequests()
 {
     m_followRequestCount++;
