@@ -73,6 +73,8 @@ public:
     Q_INVOKABLE void statusNotification();
     Q_INVOKABLE void updateNotification();
     Q_INVOKABLE void pollNotification();
+    Q_INVOKABLE void annualReportNotification();
+    Q_INVOKABLE void unknownNotification();
 
     Q_INVOKABLE void increaseFollowRequests();
     Q_INVOKABLE void decreaseFollowRequests();
@@ -82,4 +84,5 @@ private:
 
     QHash<QUrl, QNetworkReply *> m_postReplies;
     QHash<QUrl, QNetworkReply *> m_getReplies;
+    QNetworkReply *m_errorReply;
 };
